summaryrefslogtreecommitdiff
path: root/generate/src/gabble-media-channel.c
diff options
context:
space:
mode:
authorRobert McQueen <robert.mcqueen@collabora.co.uk>2006-08-22 14:45:58 +0000
committerRobert McQueen <robert.mcqueen@collabora.co.uk>2006-08-22 14:45:58 +0000
commit8fb775ceeeb7423b1a6355a5996be4f90780174e (patch)
tree313f758d52da4761732375b410aea5c26ca9dd40 /generate/src/gabble-media-channel.c
parent7d6ddb51de4ea1547d97d276b10bcf9764d1acec (diff)
regenerate gobject stubs with Channel.Interface.IceSignalling from spec 0.13.3
Diffstat (limited to 'generate/src/gabble-media-channel.c')
-rw-r--r--generate/src/gabble-media-channel.c60
1 files changed, 49 insertions, 11 deletions
diff --git a/generate/src/gabble-media-channel.c b/generate/src/gabble-media-channel.c
index c08269e7b..47406e994 100644
--- a/generate/src/gabble-media-channel.c
+++ b/generate/src/gabble-media-channel.c
@@ -35,7 +35,9 @@ enum
CLOSED,
GROUP_FLAGS_CHANGED,
MEMBERS_CHANGED,
- NEW_MEDIA_SESSION_HANDLER,
+ NEW_ICE_SESSION_HANDLER,
+ STREAM_ADDED,
+ STREAM_REMOVED,
STREAM_STATE_CHANGED,
LAST_SIGNAL
};
@@ -100,17 +102,17 @@ gabble_media_channel_class_init (GabbleMediaChannelClass *gabble_media_channel_c
gabble_media_channel_marshal_VOID__STRING_BOXED_BOXED_BOXED_BOXED_INT_INT,
G_TYPE_NONE, 7, G_TYPE_STRING, DBUS_TYPE_G_UINT_ARRAY, DBUS_TYPE_G_UINT_ARRAY, DBUS_TYPE_G_UINT_ARRAY, DBUS_TYPE_G_UINT_ARRAY, G_TYPE_UINT, G_TYPE_UINT);
- signals[NEW_MEDIA_SESSION_HANDLER] =
- g_signal_new ("new-media-session-handler",
+ signals[NEW_ICE_SESSION_HANDLER] =
+ g_signal_new ("new-ice-session-handler",
G_OBJECT_CLASS_TYPE (gabble_media_channel_class),
G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
0,
NULL, NULL,
- gabble_media_channel_marshal_VOID__INT_STRING_STRING,
- G_TYPE_NONE, 3, G_TYPE_UINT, DBUS_TYPE_G_OBJECT_PATH, G_TYPE_STRING);
+ gabble_media_channel_marshal_VOID__STRING_STRING,
+ G_TYPE_NONE, 2, DBUS_TYPE_G_OBJECT_PATH, G_TYPE_STRING);
- signals[STREAM_STATE_CHANGED] =
- g_signal_new ("stream-state-changed",
+ signals[STREAM_ADDED] =
+ g_signal_new ("stream-added",
G_OBJECT_CLASS_TYPE (gabble_media_channel_class),
G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
0,
@@ -118,6 +120,24 @@ gabble_media_channel_class_init (GabbleMediaChannelClass *gabble_media_channel_c
gabble_media_channel_marshal_VOID__INT_INT_INT,
G_TYPE_NONE, 3, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT);
+ signals[STREAM_REMOVED] =
+ g_signal_new ("stream-removed",
+ G_OBJECT_CLASS_TYPE (gabble_media_channel_class),
+ G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
+ 0,
+ NULL, NULL,
+ gabble_media_channel_marshal_VOID__INT,
+ G_TYPE_NONE, 1, G_TYPE_UINT);
+
+ signals[STREAM_STATE_CHANGED] =
+ g_signal_new ("stream-state-changed",
+ G_OBJECT_CLASS_TYPE (gabble_media_channel_class),
+ G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
+ 0,
+ NULL, NULL,
+ gabble_media_channel_marshal_VOID__INT_INT,
+ G_TYPE_NONE, 2, G_TYPE_UINT, G_TYPE_UINT);
+
dbus_g_object_type_install_info (G_TYPE_FROM_CLASS (gabble_media_channel_class), &dbus_glib_gabble_media_channel_object_info);
}
@@ -371,7 +391,7 @@ gboolean gabble_media_channel_get_self_handle (GabbleMediaChannel *obj, guint* r
* gabble_media_channel_get_session_handlers
*
* Implements DBus method GetSessionHandlers
* on interface org.freedesktop.Telepathy.Channel.Type.StreamedMedia
*
* @error: Used to return a pointer to a GError detailing any error
* that occured, DBus will throw the error only if this
@@ -386,9 +406,9 @@ gboolean gabble_media_channel_get_session_handlers (GabbleMediaChannel *obj, GPt
/**
- * gabble_media_channel_get_streams
+ * gabble_media_channel_list_streams
*
* Implements DBus method GetStreams
* on interface org.freedesktop.Telepathy.Channel.Type.StreamedMedia
*
* @error: Used to return a pointer to a GError detailing any error
@@ -397,7 +417,7 @@ gboolean gabble_media_channel_get_session_handlers (GabbleMediaChannel *obj, GPt
*
* Returns: TRUE if successful, FALSE if an error was thrown.
*/
-gboolean gabble_media_channel_get_streams (GabbleMediaChannel *obj, GPtrArray ** ret, GError **error)
+gboolean gabble_media_channel_list_streams (GabbleMediaChannel *obj, GPtrArray ** ret, GError **error)
{
return TRUE;
}
@@ -420,3 +440,21 @@ gboolean gabble_media_channel_remove_members (GabbleMediaChannel *obj, const GAr
return TRUE;
}
+
+/**
+ * gabble_media_channel_request_streams
+ *
+ * Implements DBus method RequestStreams
+ * on interface org.freedesktop.Telepathy.Channel.Type.StreamedMedia
+ *
+ * @error: Used to return a pointer to a GError detailing any error
+ * that occured, DBus will throw the error only if this
+ * function returns false.
+ *
+ * Returns: TRUE if successful, FALSE if an error was thrown.
+ */
+gboolean gabble_media_channel_request_streams (GabbleMediaChannel *obj, guint contact_handle, const GArray * types, GArray ** ret, GError **error)
+{
+ return TRUE;
+}
+
@@ -371,7 +391,7 @@ gboolean gabble_media_channel_get_self_handle (GabbleMediaChannel *obj, guint* r
*
* Implements DBus method GetSessionHandlers
- * on interface org.freedesktop.Telepathy.Channel.Type.StreamedMedia
+ * on interface org.freedesktop.Telepathy.Channel.Interface.IceSignalling
*
* @error: Used to return a pointer to a GError detailing any error
@@ -386,9 +406,9 @@ gboolean gabble_media_channel_get_session_handlers (GabbleMediaChannel *obj, GPt
*
- * Implements DBus method GetStreams
+ * Implements DBus method ListStreams
* on interface org.freedesktop.Telepathy.Channel.Type.StreamedMedia
*